pub(crate) trait ValueLookup<V: Copy> {
// Required method
fn item_value(&self, bucket: usize, item: usize) -> V;
}Expand description
Trait for bucket arrays that include storage for values
Values are opaque data, any Copy type may be used.
Required Methods
Sourcefn item_value(&self, bucket: usize, item: usize) -> V
fn item_value(&self, bucket: usize, item: usize) -> V
Retrieve the Value for a particular item
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".