Solution

Struct Solution 

pub struct Solution {
    items: SolutionItemArray,
}
Potential solution to an EquiX puzzle

The Solution type itself verifies the well-formedness of an Equi-X solution, but not its suitability for a particular challenge string.

Fields

items: SolutionItemArray

Inner fixed-sized array of SolutionItem

Implementations

Source

impl Solution

pub const NUM_ITEMS: usize

Number of items (selected hash inputs) in each solution

pub const NUM_BYTES: usize

Number of bytes in the packed representation of a solution

const ITEM_SIZE: usize

Size of each SolutionItem, in bytes

pub fn try_from_array(items: &SolutionItemArray) -> Result<Self, Error>

Build a Solution from an array of items, checking that the solution is well-formed.

pub(crate) fn sort_from_array(items: SolutionItemArray) -> Self

Build a Solution by sorting a SolutionItemArray as necessary, without the possibility of failure.

Used by the solver.

pub fn try_from_bytes(bytes: &SolutionByteArray) -> Result<Self, Error>

Build a Solution from a fixed size byte array, checking that the solution is well-formed.

pub fn to_bytes(&self) -> SolutionByteArray

Return the packed byte representation of this Solution.