pub struct BucketArrayMemory<const N: usize, const M: usize, T: Copy>([[MaybeUninit<T>; M]; N]);Expand description
Tuple Fields
0: [[MaybeUninit<T>; M]; N]Trait Implementations
impl<const N: usize, const M: usize, T: Copy + Copy> Copy for BucketArrayMemory<N, M, T>
Sourceimpl<const N: usize, const M: usize, T: Copy> Uninit for BucketArrayMemory<N, M, T>
Implements the Uninit trait. This memory is always assumed to be
uninitialized unless we hold a mutable reference paired with bucket
usage information.
impl<const N: usize, const M: usize, T: Copy> Uninit for BucketArrayMemory<N, M, T>
Implements the Uninit trait. This memory is always assumed to be
uninitialized unless we hold a mutable reference paired with bucket
usage information.
SAFETY: We can implement Uninit for BucketArrayMemory
because it’s Copy and it contains only MaybeUninit bits.