pub(crate) trait Count: Count + TryFrom<usize> {
// Provided method
fn from_item_index(i: usize) -> Self { ... }
}Expand description
Trait for types that can be used as a count of items in a bucket
Whereas mem::Count is meant to be the minimum for that module’s
purposes, this is an extended trait with features needed by the rest of
the crate.
Provided Methods
Sourcefn from_item_index(i: usize) -> Self
fn from_item_index(i: usize) -> Self
Convert from a usize item index, panic on overflow
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".